# SuccessResponseTokenRevokeResponseE7ebca9TokenRevokeResponse

Response after revoking a token.

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**message** | **str** | Status message | 
**status** | **str** | New status | [optional] [default to 'revoked']
**token_id** | **str** | Revoked token ID | 

## Example

```python
from highway_sdk.models.success_response_token_revoke_response_e7ebca9_token_revoke_response import SuccessResponseTokenRevokeResponseE7ebca9TokenRevokeResponse

# TODO update the JSON string below
json = "{}"
# create an instance of SuccessResponseTokenRevokeResponseE7ebca9TokenRevokeResponse from a JSON string
success_response_token_revoke_response_e7ebca9_token_revoke_response_instance = SuccessResponseTokenRevokeResponseE7ebca9TokenRevokeResponse.from_json(json)
# print the JSON string representation of the object
print(SuccessResponseTokenRevokeResponseE7ebca9TokenRevokeResponse.to_json())

# convert the object into a dict
success_response_token_revoke_response_e7ebca9_token_revoke_response_dict = success_response_token_revoke_response_e7ebca9_token_revoke_response_instance.to_dict()
# create an instance of SuccessResponseTokenRevokeResponseE7ebca9TokenRevokeResponse from a dict
success_response_token_revoke_response_e7ebca9_token_revoke_response_from_dict = SuccessResponseTokenRevokeResponseE7ebca9TokenRevokeResponse.from_dict(success_response_token_revoke_response_e7ebca9_token_revoke_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


